pub struct Song {Show 30 fields
pub version: Version,
pub clipboard: Option<Clipboard>,
pub name: String,
pub subtitle: String,
pub artist: String,
pub album: String,
pub words: String,
pub author: String,
pub date: String,
pub copyright: String,
pub writer: String,
pub transcriber: String,
pub instructions: String,
pub comments: String,
pub notice: Vec<String>,
pub tracks: Vec<Track>,
pub measure_headers: Vec<MeasureHeader>,
pub channels: Vec<MidiChannel>,
pub lyrics: Lyrics,
pub tempo: i16,
pub hide_tempo: bool,
pub tempo_name: String,
pub key: KeySignature,
pub triplet_feel: TripletFeel,
pub master_effect: RseMasterEffect,
pub page_setup: PageSetup,
pub current_measure_number: Option<usize>,
pub current_track: Option<usize>,
pub current_voice_number: Option<usize>,
pub current_beat_number: Option<usize>,
}Fields
version: Versionclipboard: Option<Clipboard>name: Stringsubtitle: Stringartist: Stringalbum: Stringwords: Stringdate: Stringcopyright: Stringwriter: StringTab writer
transcriber: Stringinstructions: Stringcomments: Stringnotice: Vec<String>tracks: Vec<Track>measure_headers: Vec<MeasureHeader>channels: Vec<MidiChannel>lyrics: Lyricstempo: i16hide_tempo: booltempo_name: Stringkey: KeySignaturetriplet_feel: TripletFeelmaster_effect: RseMasterEffectpage_setup: PageSetupcurrent_measure_number: Option<usize>current_track: Option<usize>current_voice_number: Option<usize>current_beat_number: Option<usize>Implementations
Sourceimpl Song
impl Song
Sourcepub fn read_gp3(&mut self, data: &[u8])
pub fn read_gp3(&mut self, data: &[u8])
Read the song. A song consists of score information, triplet feel, tempo, song key, MIDI channels, measure and track count, measure headers, tracks, measures.
- Version:
byte-size-stringof size 30. - Score information. See
readInfo. - Triplet feel:
bool. If value is true, then triplet feel is set to eigth. - Tempo:
int. - Key:
int. Key signature of the song. - MIDI channels. See
readMidiChannels. - Number of measures:
int. - Number of tracks:
int. - Measure headers. See
readMeasureHeaders. - Tracks. See
read_tracks(). - Measures. See
read_measures().
Sourcepub fn read_gp4(&mut self, data: &[u8])
pub fn read_gp4(&mut self, data: &[u8])
Read the song. A song consists of score information, triplet feel, tempo, song key, MIDI channels, measure and track count, measure headers, tracks, measures.
- Version:
byte-size-stringof size 30. - Score information. See
readInfo. - Triplet feel:
bool. If value is true, then triplet feel is set to eigth. - Lyrics. See
read_lyrics(). - Tempo:
int. - Key:
int. Key signature of the song. - Octave:
signed-byte. Reserved for future uses. - MIDI channels. See
readMidiChannels. - Number of measures:
int. - Number of tracks:
int. - Measure headers. See
readMeasureHeaders. - Tracks. See
read_tracks(). - Measures. See
read_measures().
pub fn read_gp5(&mut self, data: &[u8])